/****************************************************************/
/*   IMPLEMENTATION OF DIGITAL FILTERS WITH THE			*/
/*   WE(R) DSP32 DIGITAL SIGNAL PROCESSOR			*/
/*   April, 1988 Doc# AP88-09DMOS				*/
/****************************************************************/
/*	 Copyright (c) 1988 AT&T -- All Rights Reserved		*/
/*   WE is a registered trademark of AT&T. AT&T reserves the	*/
/*   right to make changes to  the software described herein	*/
/*   without notice.  No liability is assumed as a result of	*/
/*   their  use or  application.  No rights under any patent	*/
/*   accompany the sale of product.				*/
/****************************************************************/
/*			fir32_2.s				*/
/****************************************************************/
/*								*/
/* FIR FILTER EXAMPLE						*/
/*     The following example, in Program 2, illustrates the	*/
/* implementation of an FIR filter using the fir routine in	*/
/* Program 1. The order of the FIR filter is 19, and the program*/
/* computes the filter's unit-pulse response.  Main gets its	*/
/* input from the file in_data and stores its outputs in the	*/
/* file out_data. Twenty-four data points are used.  When	*/
/* Program 2 is run on the DSP32 simulator or the development	*/
/* system, a breakpoint can be set at the label, "pause."	*/
/* This allows the examination of the results.			*/
/*     At the breakpoint, the 24 output samples beginning at	*/
/* the location out_data, should have the following values:	*/
/*								*/
/*   float  -.414601e-2,  .158582e-1, -.429670e-1,  .947862e-1	*/
/*   float  -.186788,     .340385,    -.601026,     .109415e1	*/
/*   float  -.245254e1,  0.0,          .245254e1,  -.109415e1 	*/
/*   float   .601026,    -.340385,     .186788,    -.947862e-1	*/
/*   float   .429670e-1  -.158582e-1,  .414601e-2, 0.0		*/
/*   float  0.0,         0.0,         0.0,         0.0		*/
/****************************************************************/

/* PROGRAM 2. FIR FILTER EXAMPLE				*/
/*  to make using application library DSP32SL/lib/libap32.a	*/
/*            d3make -N fir32_2.s -lap32			*/

main:	r13 = 22			/* use as a loop counter */
	r12 = in_data			/* initialize 4 pointers */
	r11 = out_data
	r10 = in
	r9  = out

loop:	*r10 = a3 = *r12++		/* stores an input value */

	call fir (r14)			/* routine call	    */
	nop				/* latent instruction      */
int	19				/* passing the 5 arguments */
int	in, out
int	fircoef, firS00
.align 4				/* set proper alignment    */
	*r11++ = a3 = *r9		/* stores a result    */
	if (r13-- >=0) goto loop	/* test counter value */
	nop

pause:	goto pause			/* next instr. executed after */
	nop				/* the 24th routine call      */

in_data: float 1.0			/* stores the input values    */
	23*float 0.0
 
out_data: 24*float 0.0			/* initialize output values   */

in:	float 0.0			/* input value for the routine  */
out:	float 0.0			/* returned output sample value */


fircoef:	/* filter coefficients stored here */
	float  0.414601e-2, -0.158582e-1,  0.429670e-1, -0.947862e-1
	float  0.186788,    -0.340385,     0.601026,    -0.109415e1
	float  0.245254e1,   0.,          -0.245254e1,   0.109415e1 
	float -0.601026,     0.340385,    -0.186788,     0.947862e-1
	float -0.429670e-1,  0.158582e-1, -0.414601e-2

/* Assembler directive to place static variables in bank 1 */
.rsect ".hi_ram"

firS00:  18*float 0.0	/* all static variables initialized to zero. */

/* End of fir32_2.s */
