/****************************************************************/
/*   IMPLEMENTATION OF DIGITAL FILTERS WITH THE			*/
/*   WE(R) DSP32 DIGITAL SIGNAL PROCESSOR			*/
/*   April, 1988 Doc# AP88-09DMOS				*/
/****************************************************************/
/*	 Copyright (c) 1988 AT&T -- All Rights Reserved		*/
/*   WE is a registered trademark of AT&T. AT&T reserves the	*/
/*   right to make changes to  the software described herein	*/
/*   without notice.  No liability is assumed as a result of	*/
/*   their  use or  application.  No rights under any patent	*/
/*   accompany the sale of product.				*/
/****************************************************************/
/*			iir32_6.s				*/
/****************************************************************/
/* IIR FILTER EXAMPLE						*/
/* The main program in Program 6 calls a two-section IIR filter	*/
/* via the iir routine. The example assumes analog input and	*/
/* output using the AT&T T7500 u-law/A-law Codec and a sample	*/
/* rate of 8 kHz. The main program saves an input sample value,	*/
/* calls the iir routine, outputs a sample response, and repeats*/
/* the process.  This filter has a passband from 0 to 1 kHz and	*/
/* a stopband beginning at 2 kHz with loss greater than 40 dB.	*/
/****************************************************************/

/* Program 6. IIR Filter Example				*/
/*  to make using application library DSP32SL/lib/libap32.a	*/
/*    d3make -N iir32_6.s -lap32  (expect 2 warning messages)	*/

main:	ioc = 0x547	/* mu-law/A-law codec using DSP32 clocks */
	dauc = 0	/* mu-law conversion is chosen           */
	r10 = in	/* input sample value stores in &in      */
	r9  = out	/* output sample stores in &out          */
   
sample: if (ibe) goto sample	/* wait for a new sample */
	nop

	call iir (r14)		/* routine calls */
	*r10 = a0 = ic(ibuf)	/* latent instruction, stores and */
				/* converts the new sample value  */
int	2			/* filter arguments passing       */
int	in, out   
int	iircoef, iirS00
.align  4

	goto sample		/* instr. executes after    */
				/*  return from iir routine */
	obuf = a0 = oc(*r9)	/*  output a result         */

in:	float 0.0		/* routine obtains input sample here */
out:	float 0.0		/* routine stores output sample here */
   
iircoef:	/* filter coefficients stored here */
	float    2.637256e-2                        /* K1 */
	float   -1.022403, 0.3256819, 1.452737,  1.0
	float   -1.072848, 0.7197602, 0.1447465, 1.0

 /* assembler directive to place state variables in bank 1  */
.rsect ".hi_ram"  

iirS00: 4*float 0.0  /* four state variables initialized to 0 */

/* End of iir32_6.s */
